==============================================
Alternatives and related projects
==============================================

* https://github.com/amirmd76/boxb

* https://pypi.org/project/boundbox2d/ , https://github.com/duducosmos/boundbox2d

* https://pypi.org/project/bbox-visualizer/




